pub struct ServerResponse {Show 22 fields
pub access_ipv4: String,
pub access_ipv6: String,
pub addresses: BTreeMap<String, Vec<AddressesItem>>,
pub created: String,
pub description: Option<String>,
pub fault: Option<Fault>,
pub flavor: Flavor,
pub host_id: String,
pub id: String,
pub image: ImageEnum,
pub links: Vec<Links>,
pub locked: bool,
pub metadata: BTreeMap<String, String>,
pub name: Option<String>,
pub os_dcf_disk_config: String,
pub progress: Option<f32>,
pub status: Status,
pub tags: Vec<String>,
pub tenant_id: String,
pub trusted_image_certificates: Vec<String>,
pub updated: String,
pub user_id: String,
}Expand description
Server response representation
Fields
access_ipv4: StringIPv4 address that should be used to access this server. May be automatically set by the provider.
access_ipv6: StringIPv6 address that should be used to access this server. May be automatically set by the provider.
addresses: BTreeMap<String, Vec<AddressesItem>>The addresses for the server. Servers with status BUILD hide their
addresses information. This view is not updated immediately. Please
consult with OpenStack Networking API for up-to-date information.
created: StringThe date and time when the resource was created. The date and time stamp format is ISO 8601
CCYY-MM-DDThh:mm:ss±hh:mmFor example, 2015-08-27T09:49:58-05:00. The ±hh:mm value, if
included, is the time zone as an offset from UTC. In the previous
example, the offset value is -05:00.
description: Option<String>The description of the server. Before microversion 2.19 this was set to the server name.
New in version 2.19
fault: Option<Fault>A fault object. Only displayed when the server status is ERROR or
DELETED and a fault occurred.
flavor: FlavorBefore microversion 2.47 this contains the ID and links for the flavor used to boot the server instance. This can be an empty object in case flavor information is no longer present in the system.
As of microversion 2.47 this contains a subset of the actual flavor information used to create the server instance, represented as a nested dictionary.
host_id: StringAn ID string representing the host. This is a hashed value so will not actually look like a hostname, and is hashed with data from the project_id, so the same physical host as seen by two different project_ids, will be different. It is useful when within the same project you need to determine if two instances are on the same or different physical hosts for the purposes of availability or performance.
id: StringThe UUID of the server.
image: ImageEnumThe UUID and links for the image for your server instance. The image
object will be an empty string when you boot the server from a volume.
links: Vec<Links>Links to the resources in question. See API Guide / Links and References for more info.
locked: boolTrue if the instance is locked otherwise False.
New in version 2.9
metadata: BTreeMap<String, String>A dictionary of metadata key-and-value pairs, which is maintained for backward compatibility.
name: Option<String>The server name.
os_dcf_disk_config: StringDisk configuration. The value is either:
AUTO. The API builds the server with a single partition the size of the target flavor disk. The API automatically adjusts the file system to fit the entire partition.MANUAL. The API builds the server by using the partition scheme and file system that is in the source image. If the target flavor disk is larger, The API does not partition the remaining disk space.
progress: Option<f32>A percentage value of the operation progress. This parameter only
appears when the server status is ACTIVE, BUILD, REBUILD,
RESIZE, VERIFY_RESIZE or MIGRATING.
status: StatusThe server status.
A list of tags. The maximum count of tags in this list is 50.
New in version 2.26
tenant_id: StringThe UUID of the tenant in a multi-tenancy cloud.
trusted_image_certificates: Vec<String>A list of trusted certificate IDs, that were used during image
signature verification to verify the signing certificate. The list is
restricted to a maximum of 50 IDs. The value is null if trusted
certificate IDs are not set.
New in version 2.63
updated: StringThe date and time when the resource was updated. The date and time stamp format is ISO 8601
CCYY-MM-DDThh:mm:ss±hh:mmFor example, 2015-08-27T09:49:58-05:00. The ±hh:mm value, if
included, is the time zone as an offset from UTC. In the previous
example, the offset value is -05:00.
user_id: StringThe user ID of the user who owns the server.